@@ -52,7 +52,7 @@ import logging
 import mamba.mamba_api as api
 
 from mamba.post_solve_handling import post_solve_handling
-from mamba.utils import get_index, to_package_record_from_subjson
+from mamba.utils import get_index, to_package_record_from_subjson, init_api_context
 
 log = getLogger(__name__)
 stderrlog = getLogger('mamba.stderr')
@@ -81,26 +81,6 @@ banner = """
 █████████████████████████████████████████████████████████████
 """
 
-def init_api_context():
-    api_ctx = api.Context()
-    api_ctx.json = context.json
-    if context.json:
-        context.always_yes = True
-        context.quiet = True
-        context.json = False
-    api_ctx.set_verbosity(context.verbosity)
-    api_ctx.quiet = context.quiet
-    api_ctx.offline = context.offline
-    api_ctx.local_repodata_ttl = context.local_repodata_ttl
-    api_ctx.use_index_cache = context.use_index_cache
-    api_ctx.always_yes = context.always_yes
-    api_ctx.dry_run = context.dry_run
-    if context.ssl_verify == False:
-        api_ctx.ssl_verify = "<false>"
-    elif context.ssl_verify is not True:
-        api_ctx.ssl_verify = context.ssl_verify
-    api_ctx.target_prefix = context.target_prefix
-
 class MambaException(Exception):
     pass
 
@@ -492,21 +472,24 @@ def install(args, parser, command='install'):
         print_activate(args.name if args.name else prefix)
         return
 
+    spec_names = [s.name for s in specs]
+
+    if not (context.quiet or context.json):
+        print("\nLooking for: {}\n".format(spec_names))
+
     # If python was not specified, check if it is installed.
     # If yes, add the installed python to the specs to prevent updating it.
-    spec_names = [s.name for s in specs]
+    python_added = False
     if 'python' not in spec_names:
         installed_names = [i_rec.name for i_rec in installed_pkg_recs]
         if 'python' in installed_names:
             i = installed_names.index('python')
             version = installed_pkg_recs[i].version
             specs.append(MatchSpec('python==' + version))
+            python_added = True
 
     mamba_solve_specs = [s.conda_build_form() for s in specs]
 
-    if not (context.quiet or context.json):
-        print("\nLooking for: {}\n".format(mamba_solve_specs))
-
     pool = api.Pool()
 
     repos = []
@@ -539,6 +522,9 @@ def install(args, parser, command='install'):
             exit(0)
         PackageCacheData.first_writable().reload()
 
+    if python_added:
+        specs = [s for s in specs if s.name != 'python']
+
     conda_transaction = to_txn(specs, (), prefix, to_link, to_unlink, index)
     handle_txn(conda_transaction, prefix, args, newenv)
 
